==> minio-sdk-logic-0.8.4-sources.jar: cn/herodotus/oss/minio/logic/definition/pool/MinioAdminClientPooledObjectFactory.java <==
/*
 * Copyright (c) 2020-2030 ZHENGGENGWEI(码匠君)<herodotus@aliyun.com>
 *
 * Dante Cloud licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * <http://www.apache.org/licenses/LICENSE-2.0>
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Dante OSS 采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改 Dante Cloud 源码头部的版权声明。
 * 3.请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 <https://gitee.com/herodotus/dante-oss>
 * 5.在修改包名，模块名称，项目代码等时，请注明软件出处 <https://gitee.com/herodotus/dante-oss>
 * 6.若您的项目无法满足以上几点，可申请商业授权
 */

package cn.herodotus.oss.minio.logic.definition.pool;

import cn.herodotus.oss.minio.logic.properties.MinioProperties;
import io.minio.admin.MinioAdminClient;
import org.apache.commons.pool2.BasePooledObjectFactory;
import org.apache.commons.pool2.PooledObject;
import org.apache.commons.pool2.impl.DefaultPooledObject;

/**
 * <p>Description: Minio 基础 Admin Client 池化工厂 </p>
 *
 * @author : gengwei.zheng
 * @date : 2023/6/24 17:47
 */
public class MinioAdminClientPooledObjectFactory extends BasePooledObjectFactory<MinioAdminClient> {

    private final MinioProperties minioProperties;

    public MinioAdminClientPooledObjectFactory(MinioProperties minioProperties) {
        this.minioProperties = minioProperties;
    }

    @Override
    public MinioAdminClient create() throws Exception {
        return MinioAdminClient.builder()
                .endpoint(minioProperties.getEndpoint())
                .credentials(minioProperties.getAccessKey(), minioProperties.getSecretKey())
                .build();
    }

    @Override
    public PooledObject<MinioAdminClient> wrap(MinioAdminClient minioAdminClient) {
        return new DefaultPooledObject<>(minioAdminClient);
    }
}

==> minio-sdk-logic-1.1.1-sources.jar: cn/herodotus/oss/minio/logic/definition/pool/MinioAdminClientPooledObjectFactory.java <==
/*
 * Copyright (c) 2020-2030 ZHENGGENGWEI(码匠君)<herodotus@aliyun.com>
 *
 * Dante Cloud licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * <http://www.apache.org/licenses/LICENSE-2.0>
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Dante OSS 采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改 Dante Cloud 源码头部的版权声明。
 * 3.请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 <https://gitee.com/herodotus/dante-oss>
 * 5.在修改包名，模块名称，项目代码等时，请注明软件出处 <https://gitee.com/herodotus/dante-oss>
 * 6.若您的项目无法满足以上几点，可申请商业授权
 */

package cn.herodotus.oss.minio.logic.definition.pool;

import cn.herodotus.oss.minio.logic.properties.MinioProperties;
import io.minio.admin.MinioAdminClient;
import org.apache.commons.pool2.BasePooledObjectFactory;
import org.apache.commons.pool2.PooledObject;
import org.apache.commons.pool2.impl.DefaultPooledObject;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * <p>Description: Minio 基础 Admin Client 池化工厂 </p>
 *
 * @author : gengwei.zheng
 * @date : 2023/6/24 17:47
 */
public class MinioAdminClientPooledObjectFactory extends BasePooledObjectFactory<MinioAdminClient> {

    private static final Logger log = LoggerFactory.getLogger(MinioAdminClientPooledObjectFactory.class);

    private final MinioProperties minioProperties;

    public MinioAdminClientPooledObjectFactory(MinioProperties minioProperties) {
        this.minioProperties = minioProperties;
    }

    @Override
    public MinioAdminClient create() throws Exception {
        log.debug("[Herodotus] |- Minio admin client factory create object.");
        return MinioAdminClient.builder()
                .endpoint(minioProperties.getEndpoint())
                .credentials(minioProperties.getAccessKey(), minioProperties.getSecretKey())
                .build();
    }

    @Override
    public PooledObject<MinioAdminClient> wrap(MinioAdminClient minioAdminClient) {
        log.debug("[Herodotus] |- Minio admin client factory wrap object.");
        return new DefaultPooledObject<>(minioAdminClient);
    }
}
